@@ -280,9 +280,15 @@ define!({
         pub charset: Str,
     }
 
+    pub enum ImportSource {
+        Fn(FnValue),
+        Url(UrlValue),
+        Str(Str),
+    }
+
     pub struct ImportRule {
         pub span: Span,
-        pub src: Str,
+        pub src: ImportSource,
         pub condition: Option<MediaQuery>,
     }
 
